
/*********
 *
 * JavaScript stuff for the main page.
 *
 * Take care of all buttons in the .html file that change the background image.
 *
 * This version is the most sophisticated : 
 * it looks for the buttons, and will handle any number of 'em.
 *
 *********/

/* the 'global' elements are all stored in this one object. */
var elements = {};

/* The id's of the buttons that can be clicked on to change the background.
   This list is created automatically when the page loads,
   from the id's of the buttons in the .html page. */
var element_ids = [];

/* Event handler for clicks on buttons.
   The function extracts the id from 'this',
   which will be the button that was pressed when the function is called. 
   We're assuming that background file name (i.e. kite.jpg) 
   matches the button id (i.e. <button id='kite'>...</button>).
*/
function click_element(){
  elements.body.style.backgroundImage = 'url(images/' + this.id + '.jpg)';
  this.disabled = true;  /*  elements[id].disabled = true  # same */
  this.blur();
  /* turn all the other buttons on */
  for (var i=0; i<element_ids.length; i++){
    var id = element_ids[i];
    if (id != this.id){
      elements[id].disabled = false;
    }
  }
}

/* What should happen just after the page loads. */
function init(){
  /* Go get all the id's of the buttons. */
  var button_list = document.getElementsByTagName('button');
  for (var i=0; i<button_list.length; i++){
    element_ids.push(button_list[i].id);  /* append next id to element_ids */
  }
  /* Remember these guys as global variables.  (See above.)  */
  /* Assign each an event handler. */
  elements.body = document.getElementsByTagName('body')[0]; /* 0'th body tag */
  for (var i=0; i<element_ids.length; i++){
    var id = element_ids[i];
    elements[id] = document.getElementById(id);
    elements[id].onclick = click_element;
  }
  elements['kite'].disabled = true;  /* turn off the kite button */
}

/* Tell the window to call the init() function after it loads. */
window.onload = init;
